@@ -7,8 +7,8 @@ log = logging.getLogger(__name__)
 
 
 class NoseAgentExecution(AgentExecution):
-    def __init__(self, config_data, labid, test_stage, cov_report, args):
-        super(NoseAgentExecution, self).__init__(config_data, labid, test_stage, cov_report=cov_report)
+    def __init__(self, config_data, labid, test_stage, cov_report, per_test, interval, args):
+        super(NoseAgentExecution, self).__init__(config_data, labid, test_stage, cov_report=cov_report, per_test=per_test, interval=interval)
         self.args = args
 
     def execute(self):
@@ -16,6 +16,8 @@ class NoseAgentExecution(AgentExecution):
         try:
             import nose
             from python_agent.test_listener.integrations.nose_helper import SealightsNosePlugin
-            nose.main(addplugins=[SealightsNosePlugin()], argv=self.args, exit=False)
+            # first arg is ignored on parsing because it's the program name
+            self.args.insert(0, "")
+            nose.main(addplugins=[SealightsNosePlugin()], argv=self.args)
         except ImportError as e:
-            log.exception("Failed importing nose. Error: %s" % str(e))
\ No newline at end of file
+            log.exception("Failed importing nose. Error: %s" % str(e))
